# SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
# SPDX-License-Identifier: LicenseRef-NvidiaProprietary
#
# NVIDIA CORPORATION, its affiliates and licensors retain all intellectual
# property and proprietary rights in and to this material, related
# documentation and any modifications thereto. Any use, reproduction,
# disclosure or distribution of this material and related documentation
# without an express license agreement from NVIDIA CORPORATION or
# its affiliates is strictly prohibited.

import os
import platform
import subprocess


def get_arm_target_dir():
    # TODO(DTSP-15164): Correct platform detection for containers on Jetson.
    tegra_check = subprocess.run(
        "find /proc/device-tree/ -maxdepth 1 -name 'tegra*'",
        shell=True,
        stdout=subprocess.DEVNULL,
        stderr=subprocess.DEVNULL,
    )
    desktop_check = subprocess.run(
        "lsmod | grep 'nvidia'",
        shell=True,
        stdout=subprocess.DEVNULL,
        stderr=subprocess.DEVNULL,
    )

    if tegra_check.returncode == 0:
        return "target-linux-tegra-armv8"
    elif desktop_check.returncode == 0:
        return "target-linux-sbsa-armv8"
    return None


NSYS_TARGET_DIR = None
if platform.system() == "Windows":
    NSYS_EXE_NAME = "nsys.exe"
    NSYS_HOST_DIR = "host-windows-x64"
    NSYS_TARGET_DIR = "target-windows-x64"
    NSYS_SQLITE_LIB = "sqlite3.dll"
elif platform.system() == "Linux":
    NSYS_EXE_NAME = "nsys"
    NSYS_SQLITE_LIB = "libsqlite3.so.0"
    if platform.machine() == "x86_64":
        NSYS_HOST_DIR = "host-linux-x64"
        NSYS_TARGET_DIR = "target-linux-x64"
    elif platform.machine() == "aarch64":
        NSYS_HOST_DIR = "host-linux-armv8"
        NSYS_TARGET_DIR = get_arm_target_dir()

if NSYS_TARGET_DIR is None:
    raise RuntimeError("Current platform is not supported.")

NSYS_RULE_DIR = "rules"
NSYS_REPORT_DIR = "reports"
NSYS_PYTHON_DIR = "python"

NSYS_PYTHON_LIB_DIR = os.path.join(NSYS_PYTHON_DIR, "lib")
NSYS_PYTHON_PKG_DIR = os.path.join(NSYS_PYTHON_DIR, "packages")

NSYS_RECIPE_PATH = os.path.abspath(os.path.dirname(__file__))
NSYS_RECIPE_INSTALL_PATH = os.path.join(NSYS_RECIPE_PATH, "install.py")
NSYS_RECIPE_REQ_PATH = os.path.join(NSYS_RECIPE_PATH, "requirements")
NSYS_RECIPE_THIRDPARTY_PATH = os.path.join(NSYS_RECIPE_PATH, "third_party")
NSYS_RECIPE_RECIPES_PATH = os.path.join(NSYS_RECIPE_PATH, "recipes")

NSYS_RECIPE_REQ_COMMON_PATH = os.path.join(NSYS_RECIPE_REQ_PATH, "common.txt")
NSYS_RECIPE_REQ_DASK_PATH = os.path.join(NSYS_RECIPE_REQ_PATH, "dask.txt")
NSYS_RECIPE_REQ_JUPYTER_PATH = os.path.join(NSYS_RECIPE_REQ_PATH, "jupyter.txt")
